from fastapi import APIRouter, Depends, HTTPException
from .. import models, schemas
from ..dependencies import get_token_header
from sqlalchemy.orm import Session

def get_db():
    db = SessionLocal()
    try:
        yield db
    finally:
        db.close()

router = APIRouter(
    prefix="/items",
    tags=["items"],
    dependencies=[Depends(get_token_header)],
    responses={404: {"description": "Not found"}}
)

@router.get("/items", tags=["items"], response_model=schemas.items.Item)
def get_items(db:Session= Depends(get_db), skip: int = 0, limit: int = 100):
    return db.query(models.items.Item).offset(skip).limit(limit).all()

@router.post("/items", tags=["items"], response_model=schemas.items.Item)
def create_user_items(item: schemas.items.ItemCreate, user_id: int, db: Session= Depends(get_db)):
    db_item = models.items.Item(**item.dict(), owner_id=user_id)
    db.add(db_item)
    db.commit()
    db.refresh(db_item)
    return db_item